@@ -41,6 +41,8 @@
 
 #define KCMUTILS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KCMUTILS_NO_DEPRECATED) && !defined(KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x57200
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x54200
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KCMUTILS_DEPRECATED
-#  define KCMUTILS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCMUTILS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCMUTILS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -113,51 +115,7 @@
 #else
 #  define KCMUTILS_DEPRECATED_VERSION_5_66(text)
 #endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
-#  define KCMUTILS_DEPRECATED_VERSION_5_76(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_76(text)
-#endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55200
-#  define KCMUTILS_DEPRECATED_VERSION_5_82(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_82(text)
-#endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55500
-#  define KCMUTILS_DEPRECATED_VERSION_5_85(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_85(text)
-#endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55700
-#  define KCMUTILS_DEPRECATED_VERSION_5_87(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_87(text)
-#endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55800
-#  define KCMUTILS_DEPRECATED_VERSION_5_88(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_88(text)
-#endif
-
-#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55a00
-#  define KCMUTILS_DEPRECATED_VERSION_5_90(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCMUTILS_DEPRECATED_VERSION_5_90(text)
-#endif
 #define KCMUTILS_DEPRECATED_VERSION_5(minor, text)      KCMUTILS_DEPRECATED_VERSION_5_##minor(text)
 #define KCMUTILS_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION(major, minor, text)
-#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KCMUTILS_EXPORT_H */
